@@ -47,6 +47,7 @@ class {package_name}Conan(Sense2File):
        "Homepage": "www.example.com",
     }}
     deb_changelog = "my changelog"
+    # deb_install_folder = ""
     
     ## user and channel for uploading cpp package to artifactory
     # user="user"
@@ -82,6 +83,7 @@ class {package_name}Conan(Sense2File):
         self.copy("*.so", dst="lib", keep_path=False)
         self.copy("*.a", dst="lib", keep_path=False)
         self.copy("*", dst="bin", src="bin")
+        self.copy("*", dst="config", src="config")
         
 """
 
